@@ -18,6 +18,7 @@ Traits-based user interface.
 #  Imports:
 #-------------------------------------------------------------------------
 
+from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 
 from traits.api \
@@ -28,6 +29,7 @@ from traitsui.editor_factory \
 
 from .editor \
     import Editor
+import six
 
 #-------------------------------------------------------------------------
 #  'EditorFactory' class
@@ -109,7 +111,7 @@ class TextEditor(Editor):
         if self.control is None:
             return
         try:
-            self.value = str(self.control.text())
+            self.value = six.text_type(self.control.text())
         except TraitError as excp:
             pass
 
