@@ -16,6 +16,7 @@
 """
 
 # Standard library imports.
+from __future__ import absolute_import
 import logging
 
 # System library imports.
@@ -24,6 +25,7 @@ from pyface.qt import QtGui
 # Enthought library imports.
 from traits.api import File, List, Str
 from traitsui.view import View
+from io import open
 
 # Logger.
 logger = logging.getLogger(__name__)
@@ -58,7 +60,7 @@ class QtView(View):
 
         if self.style_sheet_path:
             try:
-                with open(self.style_sheet_path, 'r') as f:
+                with open(self.style_sheet_path, 'r', encoding='utf8') as f:
                     ui.control.setStyleSheet(f.read())
             except IOError:
                 logger.exception("Error loading Qt style sheet")
