@@ -11,6 +11,7 @@
 """ Defines file editors for the PyQt user interface toolkit.
 """
 
+from __future__ import absolute_import
 from os.path import abspath, splitext, isfile, exists
 
 from pyface.qt import QtCore, QtGui
@@ -22,6 +23,7 @@ from traits.api import List, Event, File, Unicode, TraitError
 from traitsui.editors.file_editor import ToolkitEditorFactory
 from .text_editor import SimpleEditor as SimpleTextEditor
 from .helper import IconButton
+import six
 
 
 is_qt5 = (QtCore.__version_info__[0] >= 5)
@@ -63,7 +65,7 @@ class SimpleEditor(SimpleTextEditor):
         """ Handles the user changing the contents of the edit control.
         """
         if self.control is not None:
-            file_name = str(self._file_name.text())
+            file_name = six.text_type(self._file_name.text())
             try:
                 if self.factory.truncate_ext:
                     file_name = splitext(file_name)[0]
@@ -90,7 +92,7 @@ class SimpleEditor(SimpleTextEditor):
             files = dlg.selectedFiles()
 
             if len(files) > 0:
-                file_name = str(files[0])
+                file_name = six.text_type(files[0])
 
                 if self.factory.truncate_ext:
                     file_name = splitext(file_name)[0]
@@ -199,7 +201,7 @@ class CustomEditor(SimpleTextEditor):
         """ Handles the user changing the contents of the edit control.
         """
         if self.control is not None:
-            path = str(self._model.filePath(idx))
+            path = six.text_type(self._model.filePath(idx))
 
             if self.factory.allow_dir or isfile(path):
                 if self.factory.truncate_ext:
@@ -221,7 +223,7 @@ class CustomEditor(SimpleTextEditor):
     def _on_dclick(self, idx):
         """ Handles the user double-clicking on a file name.
         """
-        self.dclick = str(self._model.filePath(idx))
+        self.dclick = six.text_type(self._model.filePath(idx))
 
     # Trait change handlers --------------------------------------------------
 
