@@ -1,4 +1,5 @@
 
+from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 from pyface.qt.QtGui import QFont
 
@@ -8,6 +9,8 @@ from traits.api import Dict
 # as in the default date_editor.
 from .date_editor import SimpleEditor
 from .date_editor import CustomEditor as DateCustomEditor
+import six
+from six.moves import map
 
 
 class CustomEditor(DateCustomEditor):
@@ -38,7 +41,7 @@ class CustomEditor(DateCustomEditor):
         # way to handle this is to reset the text formats of all the dates
         # in the old dict, and then set the dates in the new dict.
         if old:
-            [list(map(self._reset_formatting, dates)) for dates in list(old.values())]
+            [list(map(self._reset_formatting, dates)) for dates in old.values()]
         if new:
             styles = getattr(self.object, self.factory.styles_trait, None)
             self._apply_styles(styles, new)
@@ -52,13 +55,13 @@ class CustomEditor(DateCustomEditor):
 
         # Handle the removed items by resetting them
         [list(map(self._reset_formatting, dates))
-         for dates in list(event.removed.values())]
+         for dates in event.removed.values()]
 
     def _styles_changed(self, old, new):
         groups = getattr(self.object, self.factory.dates_trait, {})
         if not new:
             # If no new styles, then reset all the dates to a default style
-            [list(map(self._reset_formatting, dates)) for dates in list(groups.values())]
+            [list(map(self._reset_formatting, dates)) for dates in groups.values()]
         else:
             self._apply_styles(new, groups)
         return
@@ -84,10 +87,7 @@ class CustomEditor(DateCustomEditor):
     def _apply_style(self, style, dates):
         """ **style** is a CellFormat, **dates** is a list of datetime.date """
         for dt in dates:
-            qdt = QtCore.QDate(dt)
-            textformat = self.control.dateTextFormat(qdt)
-            self._apply_cellformat(style, textformat)
-            self.control.setDateTextFormat(qdt, textformat)
+            self.set_unselected_style(style, date)
         return
 
     def _apply_styles(self, style_dict, date_dict):
@@ -96,58 +96,15 @@ class CustomEditor(DateCustomEditor):
         """
         if not style_dict or not date_dict:
             return
-        for groupname, dates in list(date_dict.items()):
+        for groupname, dates in date_dict.items():
             cellformat = style_dict.get(groupname, None)
             if not cellformat:
                 continue
             for dt in dates:
-                qdt = QtCore.QDate(dt)
-                textformat = self.control.dateTextFormat(qdt)
-                self._apply_cellformat(cellformat, textformat)
-                self.control.setDateTextFormat(qdt, textformat)
+                self.set_unselected_style(cellformat, dt)
         return
 
     def _reset_formatting(self, dates):
         # Resets the text format on the given dates
         for dt in dates:
-            qdt = QtCore.QDate(dt)
-            self.control.setDateTextFormat(qdt, QtGui.QTextCharFormat())
-
-    def _apply_cellformat(self, cf, textformat):
-        """ Applies the formatting in the cellformat cf to the QTextCharFormat
-        object provided.
-        """
-        if cf.italics is not None:
-            textformat.setFontItalic(cf.italics)
-
-        if cf.underline is not None:
-            textformat.setFontUnderline(cf.underline)
-
-        if cf.bold is not None:
-            if cf.bold:
-                weight = QFont.Bold
-            else:
-                weight = QFont.Normal
-            textformat.setFontWeight(weight)
-
-        if cf.bgcolor is not None:
-            textformat.setBackground(self._color_to_brush(cf.bgcolor))
-
-        if cf.fgcolor is not None:
-            textformat.setForeground(self._color_to_brush(cf.fgcolor))
-
-        return
-
-    def _color_to_brush(self, color):
-        """ Returns a QBrush with the color specified in **color** """
-        brush = QtGui.QBrush()
-        if isinstance(color, str) and hasattr(QtCore.Qt, color):
-            col = getattr(QtCore.Qt, color)
-        elif isinstance(color, tuple) and len(color) == 3:
-            col = QtGui.QColor()
-            col.setRgb(*color)
-        else:
-            raise RuntimeError("Invalid color specification '%r'" % color)
-
-        brush.setColor(col)
-        return brush
+            self.apply_unselected_style(date)
