@@ -22,12 +22,13 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
+from __future__ import absolute_import, unicode_literals
 
+import six
 
 from pyface.qt import QtCore, QtGui
 
 from traitsui.ui_traits import SequenceTypes
-
 from .clipboard import PyMimeData
 
 #-------------------------------------------------------------------------
@@ -261,12 +262,12 @@ class TabularModel(QtCore.QAbstractTableModel):
         """ Reimplemented to generate MIME data containing the rows of the
             current selection.
         """
-        rows = sorted(set([index.row() for index in indexes]))
+        rows = sorted({index.row() for index in indexes})
         items = [self._editor.adapter.get_drag(
             self._editor.object, self._editor.name, row)
             for row in rows]
         mime_data = PyMimeData.coerce(items)
-        data = QtCore.QByteArray(str(id(self)).encode('utf8'))
+        data = QtCore.QByteArray(six.text_type(id(self)).encode('utf8'))
         for row in rows:
             data.append((' %i' % row).encode('utf8'))
         mime_data.setData(tabular_mime_type, data)
@@ -281,7 +282,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         # this is a drag from a tabular model
         data = mime_data.data(tabular_mime_type)
         if not data.isNull() and action == QtCore.Qt.MoveAction:
-            id_and_rows = list(map(int, data.data().decode('utf8').split(' ')))
+            id_and_rows = [int(s) for s in data.data().decode('utf8').split(' ')]
             table_id = id_and_rows[0]
             # is it from ourself?
             if table_id == id(self):
@@ -314,7 +315,7 @@ class TabularModel(QtCore.QAbstractTableModel):
     def supportedDropActions(self):
         """ Reimplemented to allow items to be moved.
         """
-        return QtCore.Qt.MoveAction
+        return QtCore.Qt.MoveAction | QtCore.Qt.CopyAction
 
     #-------------------------------------------------------------------------
     #  TabularModel interface:
