@@ -17,6 +17,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
+from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 
 from traits.api \
@@ -36,6 +37,7 @@ from .editor_factory \
 
 from .constants \
     import OKColor
+import six
 
 #-------------------------------------------------------------------------
 #  'SimpleEditor' class:
@@ -165,7 +167,7 @@ class SimpleEditor(Editor):
         except AttributeError:
             value = self.control.toPlainText()
 
-        value = str(value)
+        value = six.text_type(value)
 
         try:
             value = self.evaluate(value)
@@ -246,3 +248,11 @@ class ReadonlyEditor(BaseReadonlyEditor):
             new_value = '*' * len(new_value)
 
         self.control.setText(new_value)
+
+
+#-------------------------------------------------------------------------
+#  'TextEditor' class:
+#-------------------------------------------------------------------------
+
+# Same as SimpleEditor for a text editor.
+TextEditor = SimpleEditor
