@@ -23,7 +23,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
-
+from __future__ import absolute_import
 
 from traits.api import HasPrivateTraits, Instance, Constant, Bool
 
@@ -55,7 +55,7 @@ class UIInfo(HasPrivateTraits):
         """ Binds all of the associated context objects as traits of the
             object.
         """
-        for name, value in list(self.ui.context.items()):
+        for name, value in self.ui.context.items():
             self.bind(name, value)
 
     #-------------------------------------------------------------------------
