@@ -28,7 +28,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
-
+from __future__ import absolute_import
 
 from traits.api import HasStrictTraits, List, Dict, Str, Int, Any, TraitError
 
@@ -112,7 +112,7 @@ class ViewElements(HasStrictTraits):
         # Add each item in the search order which is of the right class and
         # which is not already in the result list:
         for ves in self._get_search_order():
-            for name, ve in list(ves.content.items()):
+            for name, ve in ves.content.items():
                 if isinstance(ve, klass) and (name not in result):
                     result.append(name)
 
