@@ -22,6 +22,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
+from __future__ import absolute_import
 import wx
 
 from traits.api \
@@ -45,6 +46,7 @@ from pyface.image_resource \
 
 from .helper \
     import disconnect, disconnect_no_id
+from six.moves import range
 
 try:
     from pyface.wx.drag_and_drop \
