@@ -24,6 +24,7 @@
 #-------------------------------------------------------------------------
 
 # Make sure that importimg from this backend is OK:
+from __future__ import absolute_import
 from traitsui.toolkit import assert_toolkit_import
 assert_toolkit_import(['wx'])
 
@@ -69,7 +70,7 @@ EventSuffix = {
 }
 
 # Types of popup views:
-Popups = set(('popup', 'popover', 'info'))
+Popups = {'popup', 'popover', 'info'}
 
 #-------------------------------------------------------------------------
 #  Handles UI notification handler requests that occur on a thread other than
